a {
  -webkit-mask: url(add.png), url(substract.png);
  -webkit-mask-composite: source-over;
          mask: url(add.png) add, url(substract.png);
}

a {
  -webkit-mask: url(intersect.png), url(exclude.png);
  -webkit-mask-composite: source-in, xor;
          mask: url(intersect.png) intersect, url(exclude.png);
}

a {
  -webkit-mask: url(image.png), url(image.png), url(image.png);
  -webkit-mask-composite: source-in, source-over, xor;
          mask: url(image.png) intersect, url(image.png) add, url(image.png);
}

a {
  -webkit-mask-composite: source-over;
          mask-composite: add;
}

a {
  mask-composite:;
}

a {
  -webkit-mask-composite: source-over, source-out, xor;
          mask-composite: add, subtract, exclude;
}