.a {
  -webkit-column-break-inside: auto;
          break-inside: auto;
  -webkit-column-break-before: auto;
          break-before: auto;
  -webkit-column-break-after: auto;
          break-after: auto;
}

.b {
  -webkit-column-break-inside: avoid;
          break-inside: avoid;
}

.c {
  -webkit-column-break-inside: avoid;
          break-inside: avoid-column;
}

.d {
  break-inside: avoid-page;
}

.e {
  break-inside: avoid-region;
}

.f {
  break-inside: region;
}
