a {
  -webkit-filter: blur(10px);
          filter: blur(10px);
  -webkit-transition: -webkit-filter 2s;
  transition: -webkit-filter 2s;
  transition: filter 2s;
  transition: filter 2s, -webkit-filter 2s;
}

div {
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=50);
}

b {
  filter: alpha(opacity=100);
}

em {
  filter: Alpha(opacity=100);
}
