a {
  -webkit-background-size: 20px 20px;
     -moz-background-size: 20px;
          background-size: 20px
}

b {
  -webkit-background-size: contain;
     -moz-background-size: contain;
          background-size: contain
}
