a {
  filter: blur(10px);
  transition: filter 2s;
}

div {
  filter: progid:DXImageTransform.Microsoft.Alpha(opacity=50);
}

b {
  filter: alpha(opacity=100);
}

em {
  filter: Alpha(opacity=100);
}
