a {
  -webkit-transition: 1s;
  -moz-transition: 1s;
  transition: 1s
}

a {
  -moz-transition: 1s;
    -o-transition: 1s;
       transition: 1s
}

a {
  -webkit-border-radius: 4px;
     -moz-border-radius: 4px;
          border-radius: 4px
}
