a {
  border-radius: 4px;
  -webkit-mask: none;
          mask: none;
}

b {
  /* autoprefixer: off */
  -webkit-border-radius: 4px;
          border-radius: 4px;
  mask: none;
}

.loud {
  /*! autoprefixer: off */
  -webkit-border-radius: 4px;
          border-radius: 4px;
  mask: none;
}

.case {
  /*autoprefixer:OFF*/
  -webkit-border-radius: 4px;
          border-radius: 4px;
  mask: none;
}

@support (transition: 1s) {
  /* autoprefixer: off */
  :fullscreen {
    -webkit-border-radius: 4px;
            border-radius: 4px;
    mask: none;
  }

  ::-webkit-input-placeholder {
    /*autoprefixer: on*/
    border-radius: 4px;
    -webkit-mask: none;
            mask: none;
  }

  ::placeholder {
    /*autoprefixer: on*/
    border-radius: 4px;
    -webkit-mask: none;
            mask: none;
  }
}
