a {
  -webkit-border-radius: 5px;
     -moz-border-radius: 5px;
          border-radius: 5px;
  -webkit-border-top-left-radius: 3px;
     -moz-border-radius-topleft: 3px;
          border-top-left-radius: 3px;
  -webkit-border-bottom-right-radius: 3px;
     -moz-border-radius-bottomright: 3px;
          border-bottom-right-radius: 3px;
}
