.shorthand {
  text-decoration: overline double red;
}

.full {
  text-decoration-style: double;
}

.old {
  text-decoration: underline;
}

.global {
  text-decoration: unset;
}

.skip {
  text-decoration-skip: spaces;
}

.ink {
  text-decoration-skip-ink: auto;
}

.old-ink {
  text-decoration-skip: ink;
}
