a {
  -webkit-text-emphasis-position: over;
          text-emphasis-position: over left;
}

em {
  -webkit-text-emphasis-position: under;
          text-emphasis-position: under right;
}

.reverse {
  -webkit-text-emphasis-position: over;
          text-emphasis-position: left over;
}

.wrong {
  -webkit-text-emphasis-position: over;
          text-emphasis-position: over;
}
