.one {
  -webkit-writing-mode: horizontal-tb;
      -ms-writing-mode: lr-tb;
          writing-mode: horizontal-tb;
}
.two {
  -webkit-writing-mode: vertical-rl;
      -ms-writing-mode: tb-rl;
          writing-mode: vertical-rl;
}
.three {
  -webkit-writing-mode: vertical-lr;
      -ms-writing-mode: tb-lr;
          writing-mode: vertical-lr;
}
.rtl-vertical-rl {
  -webkit-writing-mode: vertical-rl;
      -ms-writing-mode: bt-rl;
          writing-mode: vertical-rl;
  direction: rtl;
}
.rtl-vertical-lr {
  -webkit-writing-mode: vertical-lr;
      -ms-writing-mode: bt-lr;
          writing-mode: vertical-lr;
  direction: rtl;
}
.rtl-horizontal-tb {
  -webkit-writing-mode: horizontal-tb;
      -ms-writing-mode: rl-tb;
          writing-mode: horizontal-tb;
  direction: rtl;
}
.rtl-horizontal-tb-override-direction {
  -webkit-writing-mode: horizontal-tb;
      -ms-writing-mode: lr-tb;
          writing-mode: horizontal-tb;
  direction: rtl;
  direction: ltr;
}
