
[href=:fullscreen] {}

:-webkit-full-screen a {
  box-sizing: border-box
}

:-moz-full-screen a {
  -moz-box-sizing: border-box;
       box-sizing: border-box
}

:fullscreen a {
  -moz-box-sizing: border-box;
       box-sizing: border-box
}

:-webkit-full-screen a {
  color: black
}

:-moz-full-screen a {
  color: black
}

:fullscreen a {
  color: black
}

:-moz-full-screen a {
  transform: translate3d(0, 0, 0);
}
