@supports
  ((cursor: -webkit-grab) or (cursor: grab)) or
  not ((-webkit-mask: none) or (mask: none)) and
  (color: black) {
  a {
    color: black;
  }
}

@supports not ((display: -webkit-flex) or (display: flex)) {
  a {
    color: #000;
  }
}

@supports (((-webkit-perspective: 1px) or (perspective: 1px)) and (not (-webkit-overflow-scrolling: touch))) {
  a {
    color: #000;
  }
}

@supports ((-webkit-animation-name: test) or (animation-name: test)) and (((-webkit-animation-timing-function: steps(4, end)) or (animation-timing-function: steps(4, end))) or ((-webkit-animation-timing-function: step-end) or (animation-timing-function: step-end))) {
  -webkit-animation-name: test;
          animation-name: test;
}

@supports (transition: color 1s) {
  -webkit-transition: color 1s;
  transition: color 1s;
}
