.grid {
  display: grid;
}

.a,
.b,
.c::selection,
.d:read-only,
.e::placeholder {
  color: yellow;
}

::selection {
  color: red;
}

:read-only {
  color: black;
}

.f:read-write, .g:read-write {
  background: #fff;
}
