.ignore-property {
  /* autoprefixer: ignore next */
  mask: none;
  background: linear-gradient(to bottom, white, black);
}

.ignore-property_nospaces-comment {
  /* autoprefixer:ignore next */
  mask: none;
  background: linear-gradient(to bottom, white, black);
}

/* autoprefixer: ignore next */
.ignore-rule::placeholder {
  mask: none;
}

/* autoprefixer: ignore next */
@media (min-resolution: 2dppx) {
  .ignore-at-rule::placeholder {
    mask: none;
  }
}
