.shorthand {
  -webkit-text-decoration: overline double red;
     -moz-text-decoration: overline double red;
          text-decoration: overline double red;
}

.full {
  -webkit-text-decoration-style: double;
     -moz-text-decoration-style: double;
          text-decoration-style: double;
}

.old {
  text-decoration: underline;
}

.global {
  text-decoration: unset;
}

.skip {
  -webkit-text-decoration-skip: spaces;
          text-decoration-skip: spaces;
}

.ink {
  -webkit-text-decoration-skip: ink;
          text-decoration-skip-ink: auto;
}

.old-ink {
  -webkit-text-decoration-skip: ink;
          text-decoration-skip: ink;
}
