/* autoprefixer grid: on */
/* autoprefixer grid: off */

.grid-disabled {
  /* autoprefixer: off */
  display: grid;
  grid-auto-flow: column;
}

.grid {
  display: -ms-grid;
  display: grid;
  -ms-grid-columns: 1fr 1fr 1fr;
  grid-template-columns: 1fr 1fr 1fr;
  -ms-grid-rows: 100px 100px;
  grid-template-rows: 100px 100px;
  /* autoprefixer: ignore next */
  grid-auto-flow: column;
}

.grid-status-off {
  /* autoprefixer grid: off */
  /* autoprefixer grid: off */
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: 100px 100px;
}

.grid-2 {
  display: -ms-grid;
  display: grid;
}

@supports (grid-auto-rows: 100px) {
  .disabled {
    display: grid;
    grid-auto-rows: 100px;
  }
}

.grid-autoplace-enabled {
  /* autoprefixer grid: autoplace */
  display: -ms-grid;
  display: grid;
  -ms-grid-columns: 1fr 30px 1fr 30px 1fr;
  grid-template-columns: 1fr 1fr 1fr;
  -ms-grid-rows: auto;
  grid-template-rows: auto;
  grid-gap: 30px;
}

.grid-autoplace-enabled > *:nth-child(1) {
  -ms-grid-row: 1;
  -ms-grid-column: 1;
}

.grid-autoplace-enabled > *:nth-child(2) {
  -ms-grid-row: 1;
  -ms-grid-column: 3;
}

.grid-autoplace-enabled > *:nth-child(3) {
  -ms-grid-row: 1;
  -ms-grid-column: 5;
}

.grid-autoplace-disabled {
  /* autoprefixer grid: off */
  /* autoprefixer grid: autoplace */
  grid-template-columns: 1fr 1fr 1fr;
  grid-template-rows: auto;
  grid-gap: 30px;
}

.grid-autoplace-disabled-2 {
  /* autoprefixer grid: no-autoplace */
  -ms-grid-columns: 1fr 1fr 1fr;
  grid-template-columns: 1fr 1fr 1fr;
  -ms-grid-rows: auto;
  grid-template-rows: auto;
}
