.grid {
  display: -ms-grid;
  display: grid;
}

.c::-moz-selection {
  color: yellow;
}

.e::-webkit-input-placeholder {
  color: yellow;
}

.e:-moz-placeholder {
  color: yellow;
}

.e::-moz-placeholder {
  color: yellow;
}

.e:-ms-input-placeholder {
  color: yellow;
}

.e::-ms-input-placeholder {
  color: yellow;
}

.d:-moz-read-only {
  color: yellow;
}

.a,
.b,
.c::selection,
.d:read-only,
.e::placeholder {
  color: yellow;
}

::-moz-selection {
  color: red;
}

::selection {
  color: red;
}

:-moz-read-only {
  color: black;
}

:read-only {
  color: black;
}

.f:-moz-read-write, .g:-moz-read-write {
  background: #fff;
}

.f:read-write, .g:read-write {
  background: #fff;
}
