::-webkit-input-placeholder {
  color: #999
}
:-moz-placeholder {
  color: #999
}
::-moz-placeholder {
  color: #999
}
:-ms-input-placeholder {
  color: #999
}
::-ms-input-placeholder {
  color: #999
}
::placeholder {
  color: #999
}
