.a {
  grid-area: 5 / 1 / span 1 / span 5;
}

.b {
  grid-area: span 1 / span 3 / 4 / 4;
}

.c {
  grid-area: 2 / 2;
}

.d {
  grid-area: "custom-ident";
}

.e {
  grid-area: 2 / 2 / 3 / 8;
}

.f {
  grid-area: 2 / 2 / 3;
}

/* emit warning */
.g {
  grid-area: 3 / 1;
  grid-row: 1;
  grid-column: 2;
}

.h {
  grid-area: 3 / 1;
  grid-column: 1 / span 4;
}

/* there should be no warning */
.i {
  grid-area: 3 / 1;
  grid-column-end: span 4;
}

.j {
  grid-area: 3 / 1;
  grid-row-end: span 4;
}
