a {
  -o-border-image: -o-linear-gradient(black, white) 20% stretch stretch;
     border-image: -webkit-linear-gradient(black, white) 20% fill stretch stretch;
     border-image: linear-gradient(black, white) 20% fill stretch stretch;
}
