a {
  width: -moz-available;
  width: stretch;
}

b {
  height: max-content;
}

p {
  block-size: min-content;
  min-inline-size: -moz-fit-content;
  min-inline-size: fit-content;
}

.outdated {
  width: fill;
}

.old {
  width: fill-available;
}

.ok {
  width: calc(100% - var(--jqx-circular-progress-bar-fill-size));
}

.grid {
  grid: min-content max-content / fit-content(500px);
}

.grid-template {
  grid-template: min-content / fit-content(10px) max-content;
  grid-template: max-content 1fr max-content max-content / max-content 1fr;
}

.grid-template-columns {
  grid-template-columns: minmax(100px, min-content);
}

.grid-auto-columns {
  grid-auto-columns: min-content max-content;
}

.ignore {
  width: -webkit-fill-available;
}
